Test Dijit Internal Event: "ondijitclick"

# _Widget.ondijitclick test

This tests dijit's infrastructure for catching SPACE and ENTER key clicks on nodes that aren't <button> or <a>, and therefore don't normally respond to keyboard "click events".

Clicking the first widget moves focus to the plain button, but that button itself shouldn't get a click event. (There are some subtleties about whether catch clicks on key-down or key-up so this tests to make sure we are doing the right one.)

click me using space or enter, to focus button below
click me using space or enter, to focus textarea below
hello world
clicking the button above shouldn't cause my ondijitclick handler to fire
Manual Test: Click me using space or enter to launch a JavaScript alert() from element using ondijitclick
Clicking this button should produce exactly one click event to console:
Test for bubble of click
click me click me too